@@ -519,8 +519,7 @@ mx_combo_box_update_menu (MxComboBox *box)
 }
 
 static gboolean
-mx_combo_box_button_press_event (ClutterActor       *actor,
-                                 ClutterButtonEvent *event)
+mx_combo_box_open_menu (MxComboBox *actor)
 {
   ClutterActor *menu;
 
@@ -533,26 +532,21 @@ mx_combo_box_button_press_event (ClutterActor       *actor,
   return TRUE;
 }
 
+static gboolean
+mx_combo_box_button_press_event (ClutterActor       *actor,
+                                 ClutterButtonEvent *event)
+{
+  return mx_combo_box_open_menu (MX_COMBO_BOX (actor));
+}
+
 static gboolean
 mx_combo_box_key_press_event (ClutterActor    *actor,
                               ClutterKeyEvent *event)
 {
-  MxComboBoxPrivate *priv = MX_COMBO_BOX (actor)->priv;
-  gint n_items;
-
-  n_items = g_slist_length (priv->actions);
-
   switch (event->keyval)
     {
-    case CLUTTER_KEY_Down:
-      mx_combo_box_set_index (MX_COMBO_BOX (actor),
-                              CLAMP (priv->index + 1, 0, n_items -1));
-      return TRUE;
-
-    case CLUTTER_KEY_Up:
-      mx_combo_box_set_index (MX_COMBO_BOX (actor),
-                              CLAMP (priv->index - 1, 0, n_items -1));
-      return TRUE;
+    case CLUTTER_KEY_Return:
+      return mx_combo_box_open_menu (MX_COMBO_BOX (actor));
 
     default:
       return FALSE;
@@ -855,6 +849,33 @@ mx_combo_box_remove_text (MxComboBox *box,
   mx_combo_box_update_menu (box);
 }
 
+/**
+ * mx_combo_box_remove_all:
+ * @box: A #MxComboBox
+ *
+ * Remove all the items of @box
+ *
+ * Since: 1.4
+ */
+void
+mx_combo_box_remove_all (MxComboBox *box)
+{
+  MxComboBoxPrivate *priv = box->priv;
+  GSList *l;
+
+  g_return_if_fail (MX_IS_COMBO_BOX (box));
+
+  l = priv->actions;
+  while (l)
+    {
+      g_object_unref (l->data);
+      l = g_slist_delete_link (l, l);
+    }
+  priv->actions = NULL;
+
+  mx_combo_box_update_menu (box);
+}
+
 /**
  * mx_combo_box_set_active_text:
  * @box: A #MxComboBox
