@@ -671,7 +671,8 @@ mx_scroll_view_class_init (MxScrollViewClass *klass)
 
   pspec = g_param_spec_boolean ("enable-gestures",
                                 "Enable Gestures",
-                                "Enable use of pointer gestures for scrolling",
+                                "Enable use of pointer gestures for scrolling "
+                                "if Mx was built with ClutterGesture support",
                                 FALSE,
                                 MX_PARAM_READWRITE);
   g_object_class_install_property (object_class, PROP_ENABLE_GESTURES, pspec);
@@ -992,7 +993,7 @@ mx_scroll_view_set_enable_mouse_scrolling (MxScrollView *scroll,
 
   g_return_if_fail (MX_IS_SCROLL_VIEW (scroll));
 
-  priv = MX_SCROLL_VIEW (scroll)->priv;
+  priv = scroll->priv;
 
   if (priv->mouse_scroll != enabled)
     {
@@ -1013,7 +1014,7 @@ mx_scroll_view_get_enable_mouse_scrolling (MxScrollView *scroll)
 
   g_return_val_if_fail (MX_IS_SCROLL_VIEW (scroll), FALSE);
 
-  priv = MX_SCROLL_VIEW (scroll)->priv;
+  priv = scroll->priv;
 
   return priv->mouse_scroll;
 }
@@ -1026,7 +1027,7 @@ mx_scroll_view_set_enable_gestures (MxScrollView *scroll,
 
   g_return_if_fail (MX_IS_SCROLL_VIEW (scroll));
 
-  priv = MX_SCROLL_VIEW (scroll)->priv;
+  priv = scroll->priv;
 
   if (priv->enable_gestures != enabled)
     {
