@@ -63,7 +63,6 @@ struct _MxWidgetPrivate
   ClutterActor *background_image;
   ClutterColor *bg_color;
 
-  guint         is_hovered : 1;
   guint         is_disabled : 1;
   guint         parent_disabled : 1;
 
@@ -793,13 +792,11 @@ mx_widget_enter (ClutterActor         *actor,
                  ClutterCrossingEvent *event)
 {
   MxWidget *widget = MX_WIDGET (actor);
-  MxWidgetPrivate *priv = widget->priv;
 
   /* This is also expected to handle enter events from child actors
      because they will bubble up */
 
   mx_stylable_style_pseudo_class_add (MX_STYLABLE (widget), "hover");
-  priv->is_hovered = TRUE;
 
   return FALSE;
 }
@@ -809,7 +806,6 @@ mx_widget_leave (ClutterActor         *actor,
                  ClutterCrossingEvent *event)
 {
   MxWidget *widget = MX_WIDGET (actor);
-  MxWidgetPrivate *priv = widget->priv;
 
   /* If the leave event is simply moving to a child actor then we'll
      ignore it so that the actor will retain its hover state until the
@@ -823,7 +819,6 @@ mx_widget_leave (ClutterActor         *actor,
   mx_widget_long_press_cancel (widget);
   mx_stylable_style_pseudo_class_remove (MX_STYLABLE (widget), "active");
   mx_stylable_style_pseudo_class_remove (MX_STYLABLE (widget), "hover");
-  priv->is_hovered = FALSE;
 
   return FALSE;
 }
@@ -1457,6 +1452,8 @@ mx_widget_set_has_tooltip (MxWidget *widget,
         {
           priv->tooltip = g_object_new (MX_TYPE_TOOLTIP, NULL);
           clutter_actor_set_parent (CLUTTER_ACTOR (priv->tooltip), actor);
+          if (mx_stylable_style_pseudo_class_contains (MX_STYLABLE (widget), "hover"))
+            mx_widget_show_tooltip (widget);
         }
     }
   else
@@ -1725,6 +1722,11 @@ mx_widget_set_disabled (MxWidget *widget,
     {
       priv->is_disabled = disabled;
 
+      if (disabled)
+        mx_stylable_style_pseudo_class_add (MX_STYLABLE (widget), "disabled");
+      else
+        mx_stylable_style_pseudo_class_remove (MX_STYLABLE (widget), "disabled");
+
       /* Propagate the disabled state to our children, if necessary */
       if (!priv->parent_disabled && CLUTTER_IS_CONTAINER (widget))
         _mx_widget_propagate_disabled ((ClutterContainer *) widget, disabled);
